Learn R Programming

tiledb (version 0.33.0)

allows_dups<-: Sets toggle whether the array schema allows duplicate values or not. This is only valid for sparse arrays.

Description

Sets toggle whether the array schema allows duplicate values or not. This is only valid for sparse arrays.

Usage

allows_dups(x) <- value

# S4 method for tiledb_array_schema allows_dups(x) <- value

tiledb_array_schema_set_allows_dups(x, value)

Value

An object of class tiledb_array_schema.

Arguments

x

A TileDB Schema object

value

logical value