Learn R Programming

tiledb (version 0.9.2)

array_vacuum: After consolidation, remove consilidated fragments of a TileDB Array

Description

This function can remove fragments following a consolidation step. Note that vacuuming should not be run if one intends to use the TileDB time-traveling feature of opening arrays at particular timestamps

Usage

array_vacuum(uri, cfg = NULL, ctx = tiledb_get_context())

Arguments

uri

A character value with the URI of a TileDB Array

cfg

An optional TileDB Configuration object

ctx

An option TileDB Context object

Value

NULL is returned invisibly