Learn R Programming

tiledb (version 0.11.0)

attrs,tiledb_dense,ANY-method: Retrieve attributes from tiledb_dense object

Description

By default, all attributes will be selected. But if a subset of attribute names is assigned to the internal slot attrs, then only those attributes will be queried. This methods accesses the slot.

Usage

# S4 method for tiledb_dense,ANY
attrs(object)

Arguments

object

A tiledb_dense array object

Value

An empty character vector if no attributes have been selected or else a vector with attributes.