A tiledb_array object can, if requested, return query statistics as a
JSON string in an attribute ‘query_statistics’ attached to the return
object. The default value of the logical switch is ‘FALSE’. This
method sets the value.
query_statistics(x) <- value# S4 method for tiledb_array
query_statistics(x) <- value
The modified tiledb_array array object
A tiledb_array object
A logical value with the selection