Learn R Programming

tiledb (version 0.22.0)

tiledb_array_apply_aggregate: Run an aggregate query on the given array and attribute

Description

Run an aggregate query on the given array and attribute

Usage

tiledb_array_apply_aggregate(
  array,
  attrname,
  operation = c("Count", "NullCount", "Min", "Max", "Mean", "Sum"),
  nullable = TRUE
)

Value

The value of the aggregation

Arguments

array

A TileDB Array object

attrname

The name of an attribute

operation

The name of aggregation operation

nullable

A boolean toggle whether the attribute is nullable