Delete fragments written between the start and end times given
tiledb_array_delete_fragments(arr, ts_start, ts_end)A boolean indicating success
A TileDB Array object as for example returned by tiledb_array()
A Datetime object that will be converted to millisecond granularity
A Datetime object that will be converted to millisecond granularity