tiledb_array_open: Open a TileDB Array
Description
Open a TileDB Array
Usage
tiledb_array_open(arr, type = c("READ", "WRITE"))Arguments
arr
A TileDB Array object as for example returned by tiledb_array()
type
A character value that must be either ‘READ’ or ‘WRITE’
Value
The TileDB Array object but opened for reading or writing