powered by
These functions allocate (and free) appropriate pointer objects for, respectively, Arrow array and schema objects.
tiledb_arrow_array_ptr()tiledb_arrow_schema_ptr()tiledb_arrow_array_del(ptr)tiledb_arrow_schema_del(ptr)
tiledb_arrow_schema_ptr()
tiledb_arrow_array_del(ptr)
tiledb_arrow_schema_del(ptr)
The allocating functions return the requested pointer
A external pointer object previously allocated with these functions