tiledb_group_put_metadata: Write Metadata to a TileDB Group
Description
Write Metadata to a TileDB Group
Usage
tiledb_group_put_metadata(grp, key, val)
Value
On success boolean ‘TRUE’ is returned
Arguments
- grp
A TileDB Group object as for example returned by tiledb_group()
- key
A character value with they index under which the data will be written
- val
An R object (numeric, int, or char vector) that will be stored