Learn R Programming

tiledb (version 0.33.0)

tiledb_ndim,tiledb_dim-method: Returns the number of dimensions for a tiledb domain object

Description

Returns the number of dimensions for a tiledb domain object

Usage

# S4 method for tiledb_dim
tiledb_ndim(object)

Value

An integer with the number of dimensions.

Arguments

object

A tiledb_dim object

Examples

Run this code
# \dontshow{
ctx <- tiledb_ctx(limitTileDBCores())
# }
d1 <- tiledb_dim("d1", c(1L, 10L), 10L)
tiledb_ndim(d1)

Run the code above in your browser using DataLab