tiledb_object_rm: Removes a TileDB resource
Description
Raises an error if the uri is invalid, or the uri resource is not a tiledb object
Usage
tiledb_object_rm(uri, ctx = tiledb_get_context())
Arguments
uri
path which to create group
ctx
tiledb_ctx object (optional)
Value
uri of removed TileDB resource