Learn R Programming

tiledb (version 0.9.2)

tiledb_query_alloc_buffer_ptr_char_subarray: Allocate a Query buffer for reading a character attribute using a subarray

Description

Note that this uses an API part that may be deprecated in the future.

Usage

tiledb_query_alloc_buffer_ptr_char_subarray(
  array,
  attr,
  subarray = NULL,
  sizeoffsets = 0,
  sizedata = 0
)

Arguments

array

A TileDB Array object

attr

A character value containing the attribute

subarray

A vector of length four describing the subarray required for dense arrays

sizeoffsets

An optional value of the size of the offsets vector

sizedata

An optional value of the size of the data string

Value

An external pointer to the allocated buffer object