Learn R Programming

tiledb (version 0.9.7)

tiledb_query_condition_combine: Combine two 'tiledb_query_condition' objects

Description

Combines two query condition object using a relatiional operator. Note that at present only 'AND' is supported.

Usage

tiledb_query_condition_combine(lhs, rhs, op)

Arguments

lhs

A 'tiledb_query_condition' object on the left-hand side of the relation

rhs

A 'tiledb_query_condition' object on the left-hand side of the relation

op

A character value with then relation, this must be one of 'AND', 'OR' or 'NOT'.

Value

The combined 'tiledb_query_condition' object