This function imports to the named buffer for a ‘WRITE’ query from two Arrow exerternal pointers.
tiledb_query_import_buffer(
query,
name,
arrowpointers,
ctx = tiledb_get_context()
)The update Query external pointer is returned
A TileDB Query object
A character variable identifying the buffer
A two-element list vector with two external pointers to an Arrow Array and Schema, respectively
tiledb_ctx object (optional)