tiledb_query_set_buffer_ptr: Assigns to a Query buffer for a given attribute
Description
This function assigns a given query buffer to a query.
Usage
tiledb_query_set_buffer_ptr(query, attr, bufptr)
Arguments
attr
A character value containing the attribute
bufptr
An external pointer with a query buffer
Value
The modified query object, invisibly