Learn R Programming

tiledb (version 0.26.0)

tiledb_schema_get_enumeration_status: Get Dimension or Attribute Status

Description

Note that this function is an unexported internal function.

Usage

tiledb_schema_get_enumeration_status(sch)

Value

An integer vector where each element corresponds to a schema entry, and a value of one signals dimension and a value of two an attribute.

Arguments

sch

A TileDB Schema object