This function can remove fragments following a consolidation step. Note that vacuuming should not be run if one intends to use the TileDB time-traveling feature of opening arrays at particular timestamps
array_vacuum(uri, cfg = NULL, ctx = tiledb_get_context())A character value with the URI of a TileDB Array
An optional TileDB Configuration object
An option TileDB Context object
NULL is returned invisibly