tiledb_dense objectBy default, all attributes will be selected. But if a subset of attribute
names is assigned to the internal slot attrs, then only those attributes
will be queried. This methods accesses the slot.
# S4 method for tiledb_dense,ANY
attrs(object)A tiledb_dense array object
An empty character vector if no attributes have been selected or else a vector with attributes.