The grammar for query conditions is at present constraint to six operators and three boolean types.
parse_query_condition(expr, ta = NULL, debug = FALSE, strict = TRUE)An expression that is understood by the TileDB grammar for query conditions.
An optional tiledb_array object that the query condition is applied to
A boolean toogle to enable more verbose operations, defaults to 'FALSE'.
A boolean toogle to, if set, errors if a non-existing attribute is selected or filtered on, defaults to 'TRUE'; if 'FALSE' a warning is shown by execution proceeds.
A tiledb_query_condition object