tiledb_array returns a new object. This class is experimental.
tiledb_array(
uri,
query_type = c("READ", "WRITE"),
is.sparse = NA,
as.data.frame = FALSE,
attrs = character(),
extended = TRUE,
selected_ranges = list(),
query_layout = character(),
datetimes_as_int64 = FALSE,
encryption_key = character(),
timestamp = as.POSIXct(double(), origin = "1970-01-01"),
as.matrix = FALSE,
as.array = FALSE,
query_condition = new("tiledb_query_condition"),
timestamp_start = as.POSIXct(double(), origin = "1970-01-01"),
timestamp_end = as.POSIXct(double(), origin = "1970-01-01"),
return_as = get_return_as_preference(),
query_statistics = FALSE,
sil = list(),
dumpbuffers = character(),
buffers = list(),
ctx = tiledb_get_context()
)uri path to the tiledb dense array
optionally loads the array in "READ" or "WRITE" only modes.
optional logical switch, defaults to "NA" letting array determine it
optional logical switch, defaults to "FALSE"
optional character vector to select attributes, default is empty implying all are selected
optional logical switch selecting wide ‘data.frame’
format, defaults to TRUE
optional A list with matrices where each matrix i describes the (min,max) pair of ranges for dimension i
optional A value for the TileDB query layout, defaults to an empty character variable indicating no special layout is set
optional A logical value selecting date and datetime value
representation as ‘raw’ integer64 and not as Date,
POSIXct or nanotime objects.
optional A character value with an AES-256 encryption key in case the array was written with encryption.
optional A POSIXct Datetime value determining where in time the array is to be openened. Deprecated, use ‘timestamp_start’ instead
optional logical switch, defaults to "FALSE"; currently limited to dense matrices; in the case of multiple attributes in query a list of matrices is returned
optional logical switch, defaults to "FALSE"; in the case of multiple attributes in query a list of arrays is returned
optional tiledb_query_condition object, by default uninitialized
without a condition; this functionality requires TileDB 2.3.0 or later
optional A POSIXct Datetime value determining the inclusive time point at which the array is to be openened. No fragments written earlier will be considered.
optional A POSIXct Datetime value determining the inclusive time point until which the array is to be openened. No fragments written earlier later be considered.
optional A character value with the desired tiledb_array conversion,
permitted values are ‘asis’ (default, returning a list of columns), ‘array’,
‘matrix’,‘data.frame’, ‘data.table’ or ‘tibble’; the latter
two require the respective packages installed. The existing as.* arguments take precedent
over this.
optional A logical value, defaults to ‘FALSE’; if ‘TRUE’ the query statistics are returned (as a JSON string) via the attribute ‘query_statistics’ of the return object.
optional A list, by default empty to store schema information when query objects are parsed.
An optional character variable with a directory name (relative to
/dev/shm) for writing out results buffers (for internal use / testing)
An optional list with full pathnames of shared memory buffers to read data from
optional tiledb_ctx
tiledb_array object