tiledb_array returns a new object. This class is experimental.
tiledb_array(
uri,
query_type = c("READ", "WRITE"),
is.sparse = NA,
as.data.frame = FALSE,
attrs = character(),
extended = TRUE,
selected_ranges = list(),
query_layout = character(),
datetimes_as_int64 = FALSE,
encryption_key = character(),
timestamp = as.POSIXct(double(), origin = "1970-01-01"),
as.matrix = FALSE,
ctx = tiledb_get_context()
)uri path to the tiledb dense array
optionally loads the array in "READ" or "WRITE" only modes.
optional logical switch, defaults to "NA" letting array determine it
optional logical switch, defaults to "FALSE"
optional character vector to select attributes, default is empty implying all are selected
optional logical switch selecting wide ‘data.frame’ format, defaults to "TRUE"
optional A list with matrices where each matrix i describes the (min,max) pair of ranges for dimension i
optional A value for the TileDB query layout, defaults to an empty character variable indicating no special layout is set
optional A logical value selecting date and datetime value
representation as ‘raw’ integer64 and not as Date,
POSIXct or nanotime objects.
optional A character value with an AES-256 encryption key in case the array was written with encryption.
optional A POSIXct Datetime value determining where in time the array is to be openened.
optional logical switch, defaults to "FALSE"; currently limited to dense matrices; in the case of multiple attributes in query lists of matrices are returned
tiledb_ctx (optional)
tiledb_array object