This class aims to eventually replace tiledb_dense
and tiledb_sparse provided equivalent functionality
based on refactored implementation utilising newer TileDB features.
ctxA TileDB context object
uriA character despription
is.sparseA logical value
as.data.frameA logical value
attrsA character vector
extendedA logical value
selected_rangesAn optional list with matrices where each matrix i describes the (min,max) pair of ranges for dimension i
query_layoutAn optional character value
datetimes_as_int64A logical value
encryption_keyA character value
timestampA POSIXct datetime variable (deprecated, use timestamp_start)
as.matrixA logical value
as.arrayA logical value
query_conditionA Query Condition object
timestamp_startA POSIXct datetime variable for the inclusive interval start
timestamp_endA POSIXct datetime variable for the inclusive interval start
return_asA character value with the desired tiledb_array conversion,
permitted values are ‘asis’ (default, returning a list of columns),
‘array’, ‘matrix’,‘data.frame’, ‘data.table’
or ‘tibble’; the latter two require the respective packages installed
query_statisticsA logical value, defaults to ‘FALSE’; if ‘TRUE’ the query statistics are returned (as a JSON string) via the attribute ‘query_statistics’ of the return object.
silAn optional and internal list object with schema information, used for parsing queries.
ptrExternal pointer to the underlying implementation