tiledb_query_alloc_buffer_ptr_char: Allocate a Query buffer for reading a character attribute
Description
Allocate a Query buffer for reading a character attribute
Usage
tiledb_query_alloc_buffer_ptr_char(sizeoffsets, sizedata)
Arguments
sizeoffsets
An optional value of the size of the offsets vector
sizedata
An optional value of the size of the data string
Value
An external pointer to the allocated buffer object