Note that this uses an API part that may be deprecated in the future.
tiledb_query_alloc_buffer_ptr_char_subarray(
array,
attr,
subarray = NULL,
sizeoffsets = 0,
sizedata = 0
)A TileDB Array object
A character value containing the attribute
A vector of length four describing the subarray required for dense arrays
An optional value of the size of the offsets vector
An optional value of the size of the data string
An external pointer to the allocated buffer object