This function imports to the named buffer for a ‘WRITE’ query from two Arrow C pointers.
tiledb_query_import_buffer(
query,
name,
arrowpointers,
ctx = tiledb_get_context()
)A TileDB Query object
A character variable identifying the buffer
A two-element numeric vector with two pointers to an Arrow Array and Schema, respectively
tiledb_ctx object (optional)
The update Query external pointer is returned