tiledb_sparse returns a list of coordinates and attributes vectors for reads
tiledb_sparse(
uri,
query_type = c("READ", "WRITE"),
as.data.frame = FALSE,
attrs = character(),
extended = TRUE,
ctx = tiledb_get_context()
)uri path to the tiledb dense array
optionally loads the array in "READ" or "WRITE" only modes.
optional logical switch, defaults to "FALSE"
optional character vector to select attributes, default is empty implying all are selected
optional logical switch selecting wide ‘data.frame’ format, defaults to "TRUE"
tiledb_ctx (optional)
tiledb_sparse array object
We plan to deprecate the tiledb_sparse array type in a future release. While exact
timelines have not been finalised, it is advised to the tiledb_array for both
dense and sparse arrays going forward.